==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/no-NO/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'En konto med denne e-postadressen finnes allerede.',
    'account_not_found'      => 'Brukernavnet eller passordet er feil.',
    'account_not_activated'  => 'Denne brukerkontoen er ikke aktiv.',
    'account_suspended'      => 'Denne brukerkontoen er deaktivert.',
    'account_banned'         => 'Denne brukerkontoen er forbudt.',
    'throttle'               => 'For mange mislykkede påloggingsforsøk. Prøv igjen om :minutes minutter.',

    'two_factor' => array(
        'already_enrolled'      => 'Enheten din er allerede registrert.',
        'success'               => 'Du har logget inn.',
        'code_required'         => 'To-faktor-kode er påkrevd.',
        'invalid_code'          => 'To-faktor-koden er ugyldig.',
    ),

    'signin' => array(
        'error'   => 'Det oppstod et problem under innlogging. Prøv igjen.',
        'success' => 'Vellykket innlogging.',
    ),

    'logout' => array(
        'error'   => 'Det oppstod et problem med utlogging, prøv igjen.',
        'success' => 'Du har logget ut.',
    ),

    'signup' => array(
        'error'   => 'Det oppstod et problem under opprettelse av konto. Prøv igjen.',
        'success' => 'Opprettelse av konto vellykket.',
    ),

    'forgot-password' => array(
        'error'   => 'Det oppstod et problem under henting av kode for resetting av passord. Prøv igjen.',
        'success' => 'Hvis den oppgitte e-postadressen finnes i systemet vårt har det blitt sendt en e-post med gjenopprettelse av passord.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Det oppstod et problem under gjenopprettelse av passordet ditt. Prøv igjen.',
        'success' => 'Ditt passord er resatt.',
    ),


);

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/no-NO/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'En konto med denne e-postadressen finnes allerede.',
    'account_not_found'      => 'Brukernavnet eller passordet er feil.',
    'account_not_activated'  => 'Denne brukerkontoen er ikke aktiv.',
    'account_suspended'      => 'Denne brukerkontoen er deaktivert.',
    'account_banned'         => 'Denne brukerkontoen er forbudt.',
    'throttle'               => 'For mange mislykkede påloggingsforsøk. Prøv igjen om :minutes minutter.',

    'two_factor' => array(
        'already_enrolled'      => 'Enheten din er allerede registrert.',
        'success'               => 'Du har logget inn.',
        'code_required'         => 'To-faktor-kode er påkrevd.',
        'invalid_code'          => 'To-faktor-koden er ugyldig.',
        'enter_two_factor_code' => 'Please enter your two-factor authentication code.',
        'please_enroll'         => 'Please enroll a device in two-factor authentication.',
    ),

    'signin' => array(
        'error'   => 'Det oppstod et problem under innlogging. Prøv igjen.',
        'success' => 'Vellykket innlogging.',
    ),

    'logout' => array(
        'error'   => 'Det oppstod et problem med utlogging, prøv igjen.',
        'success' => 'Du har logget ut.',
    ),

    'signup' => array(
        'error'   => 'Det oppstod et problem under opprettelse av konto. Prøv igjen.',
        'success' => 'Opprettelse av konto vellykket.',
    ),

    'forgot-password' => array(
        'error'   => 'Det oppstod et problem under henting av kode for resetting av passord. Prøv igjen.',
        'success' => 'Hvis den oppgitte e-postadressen finnes i systemet vårt har det blitt sendt en e-post med gjenopprettelse av passord.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Det oppstod et problem under gjenopprettelse av passordet ditt. Prøv igjen.',
        'success' => 'Ditt passord er resatt.',
    ),


);
